@@ -1,5 +1,5 @@
 package Test::Mock::LWP::Dispatch;
-$Test::Mock::LWP::Dispatch::VERSION = '0.07';
+$Test::Mock::LWP::Dispatch::VERSION = '0.08';
 use strict;
 use warnings;
 
@@ -128,11 +128,11 @@ BEGIN {
     }
 
     my %mock_methods = (
-         simple_request => \&simple_request,
-         map            => \&map,
-         map_passtrough => \&map_passthrough,
-         unmap          => \&unmap,
-         unmap_all      => \&unmap_all,
+         simple_request  => \&simple_request,
+         map             => \&map,
+         map_passthrough => \&map_passthrough,
+         unmap           => \&unmap,
+         unmap_all       => \&unmap_all,
     );
 
     Test::MockObject->fake_module('LWP::UserAgent', %mock_methods);
@@ -155,7 +155,7 @@ Test::Mock::LWP::Dispatch - mocks LWP::UserAgent and dispatches your requests/re
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -249,7 +249,7 @@ Method returns index of your mapping. You can use it in C<unmap>.
 
 Will pass through the $req_descr to actual LWP::UserAgent. See L<map> for $req_descr.
 
-Example to let LWP::UserAgent handle all file:// urls: C<$mock_ua-E<gt>map_passtrough(qr{^file://});>
+Example to let LWP::UserAgent handle all file:// urls: C<$mock_ua-E<gt>map_passthrough(qr{^file://});>
 
 =item unmap($map_index)
 
